==> klat4-0.5.2.tar.bz2: klat4-0.5.2/main.cpp <==
/*
    Klat - A LaTeX editor for KDE
    
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "klat.h"
#include <kapplication.h>
#include <kcmdlineargs.h>
#include <kaboutdata.h>

static KCmdLineOptions options;

int main(int argc,char *argv[])
{
	options.add("+[file(s)]",ki18n("Document(s) to open."));
	
	KAboutData aboutinfo("klat4","",ki18n("Klat4"),VERSION,ki18n("A LaTeX editor for KDE4"),KAboutData::License_GPL,ki18n( 
	                    "Copyright (C) 2002-2004  Jori Liesenborgs\n"
			    "Copyright (C) 2008  Anna A. Ladilova (aka laddassm)\n"
			    "Copyright (C) 2008  Dmitry V. Reshetnikov (aka GenSerG)\n\n"),
		            ki18n("This program is free software; you can redistribute it and/or modify\n"
		            "it under the terms of the GNU General Public License as published by\n"
		            "the Free Software Foundation; either version 2 of the License,\n"
		            "or (at your option) any later version.\n\n"
		            "This program is distributed in the hope that it will be useful,\n"
		            "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
		            "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
		            "GNU General Public License for more details.\n\n"
		            "You should have received a copy of the GNU General Public License\n"
		            "along with this program; if not, write to the Free Software\n"
		            "Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n"),
		            "http://www.algebraic.ru/",
		            "ladilova@algebraic.ru,laddassm@gmail.com");
	aboutinfo.addAuthor(ki18n("Anna A. Ladilova"));
	aboutinfo.addAuthor(ki18n("Dmitry V. Reshetnikov"));
	aboutinfo.addAuthor(ki18n("Jori Liesenborgs, author of Klat for KDE3"));
	aboutinfo.addAuthor(ki18n("Brachet Pascal, author of Kile (from which I took the mathematical symbols)"));

	KCmdLineArgs::init(argc,argv,&aboutinfo);
	KCmdLineArgs::addCmdLineOptions(options);

	KApplication app;
	KCmdLineArgs *args;
	Klat *klat;
	int i,status;
	
	klat = new Klat();
	
	args = KCmdLineArgs::parsedArgs();
	for (i = 0 ; i < args->count() ; i++)
		klat->openCommandLineFile(args->arg(i));
	
	app.setActiveWindow(klat);
	status = app.exec();
	args->clear();
	return status;
}

==> klat4-0.6.1.tar.bz2: klat4-0.6.1/main.cpp <==
/*
    Klat4 - A LaTeX editor for KDE4
    
    Copyright (C) 2008  Anna A. Ladilova (ladilova@algebraic.ru)
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "klat.h"

#include <KApplication>
#include <KCmdLineArgs>
#include <KAboutData>

static KCmdLineOptions options;

int main(int argc,char *argv[])
{
	options.add("+[file(s)]",ki18n("Document(s) to open."));
	
	KAboutData aboutinfo("klat4","",ki18n("Klat4"),VERSION,ki18n("A LaTeX editor for KDE4"),KAboutData::License_GPL,ki18n( 
	                    "Copyright (C) 2002-2004  Jori Liesenborgs\n"
			    "Copyright (C) 2008  Anna A. Ladilova (aka laddassm)\n"
			    "Copyright (C) 2008  Dmitry V. Reshetnikov (aka GenSerG)\n\n"),
		            ki18n("This program is free software; you can redistribute it and/or modify\n"
		            "it under the terms of the GNU General Public License as published by\n"
		            "the Free Software Foundation; either version 2 of the License,\n"
		            "or (at your option) any later version.\n\n"
		            "This program is distributed in the hope that it will be useful,\n"
		            "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
		            "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
		            "GNU General Public License for more details.\n\n"
		            "You should have received a copy of the GNU General Public License\n"
		            "along with this program; if not, write to the Free Software\n"
		            "Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n"),
		            "http://www.algebraic.ru/",
		            "laddassm@gmail.com");
	aboutinfo.addAuthor(ki18n("Anna A. Ladilova"));
	aboutinfo.addAuthor(ki18n("Dmitry V. Reshetnikov"));
	aboutinfo.addAuthor(ki18n("Jori Liesenborgs, author of Klat for KDE3"));


	KCmdLineArgs::init(argc,argv,&aboutinfo);
	KCmdLineArgs::addCmdLineOptions(options);

	KApplication app;
	KCmdLineArgs *args;
	Klat *klat;
	int i,status;
	
	klat = new Klat();
	
	args = KCmdLineArgs::parsedArgs();
	if(args->count() == 0)
		klat->createFirstDocument();
	else
		for (i = 0 ; i < args->count() ; i++)
			klat->openCommandLineFile(args->arg(i));
	
	app.setActiveWindow(klat);
	status = app.exec();
	args->clear();
	return status;
}
